==> l7-layers-2.20.18.tgz: package/es/tile/tile/Tile.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _regeneratorRuntime from "@babel/runtime/regenerator";
function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
import { createLayerContainer } from '@antv/l7-core';
import { EventEmitter } from 'eventemitter3';
import PolygonLayer from "../../polygon";
import { isNeedMask } from "./util";
var Tile = /*#__PURE__*/function (_EventEmitter) {
  _inherits(Tile, _EventEmitter);
  var _super = _createSuper(Tile);
  function Tile(sourceTile, parent) {
    var _this;
    _classCallCheck(this, Tile);
    _this = _super.call(this);
    _defineProperty(_assertThisInitialized(_this), "visible", true);
    _defineProperty(_assertThisInitialized(_this), "layers", []);
    _defineProperty(_assertThisInitialized(_this), "isLoaded", false);
    _defineProperty(_assertThisInitialized(_this), "tileMaskLayers", []);
    _this.parent = parent;
    _this.sourceTile = sourceTile;
    _this.x = sourceTile.x;
    _this.y = sourceTile.y;
    _this.z = sourceTile.z;
    _this.key = "".concat(_this.x, "_").concat(_this.y, "_").concat(_this.z);
    return _this;
  }
  _createClass(Tile, [{
    key: "getLayers",
    value: function getLayers() {
      return this.layers;
    }

    // eslint-disable-next-line @typescript-eslint/no-unused-vars
  }, {
    key: "styleUpdate",
    value: function styleUpdate() {
      return;
    }
  }, {
    key: "lnglatInBounds",
    value: function lnglatInBounds(lnglat) {
      var _this$sourceTile$boun = _slicedToArray(this.sourceTile.bounds, 4),
        minLng = _this$sourceTile$boun[0],
        minLat = _this$sourceTile$boun[1],
        maxLng = _this$sourceTile$boun[2],
        maxLat = _this$sourceTile$boun[3];
      var lng = lnglat.lng,
        lat = lnglat.lat;
      return lng >= minLng && lng <= maxLng && lat >= minLat && lat <= maxLat;
    }
  }, {
    key: "getLayerOptions",
    value: function getLayerOptions() {
      var _options$maskLayers;
      var options = this.parent.getLayerConfig();
      return _objectSpread(_objectSpread({}, options), {}, {
        textAllowOverlap: true,
        // 文本允许重叠
        autoFit: false,
        maskLayers: this.getMaskLayer(),
        tileMask: isNeedMask(this.parent.type),
        mask: options.mask || ((_options$maskLayers = options.maskLayers) === null || _options$maskLayers === void 0 ? void 0 : _options$maskLayers.length) !== 0 && options.enableMask
      });
    }
    // 获取Mask 图层
  }, {
    key: "getMaskLayer",
    value: function getMaskLayer() {
      var _this2 = this;
      var _this$parent$getLayer = this.parent.getLayerConfig(),
        maskLayers = _this$parent$getLayer.maskLayers;
      var layers = [];
      maskLayers === null || maskLayers === void 0 || maskLayers.forEach(function (layer) {
        if (!layer.tileLayer) {
          // 非瓦片图层返回图层本身，瓦片图层返回对应的行列号图层
          layers.push(layer);
          return layer;
        }
        var tileLayer = layer.tileLayer;
        var tile = tileLayer.getTile(_this2.sourceTile.key);
        var l = tile === null || tile === void 0 ? void 0 : tile.getLayers()[0];
        if (l) {
          layers.push(l);
        }
      });
      return layers;
    }
  }, {
    key: "addTileMask",
    value: function () {
      var _addTileMask = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        var mask, container, mainLayer;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              mask = new PolygonLayer({
                name: 'mask',
                visible: true,
                enablePicking: false
              }).source({
                type: 'FeatureCollection',
                features: [this.sourceTile.bboxPolygon]
              }, {
                parser: {
                  type: 'geojson',
                  featureId: 'id'
                }
              }).shape('fill').color('#0f0').style({
                opacity: 0.5
              });
              container = createLayerContainer(this.parent.sceneContainer);
              mask.setContainer(container, this.parent.sceneContainer);
              _context.next = 5;
              return mask.init();
            case 5:
              this.tileMask = mask;
              mainLayer = this.getMainLayer();
              if (mainLayer !== undefined) {
                mainLayer.tileMask = mask;
              }
              return _context.abrupt("return", mask);
            case 9:
            case "end":
              return _context.stop();
          }
        }, _callee, this);
      }));
      function addTileMask() {
        return _addTileMask.apply(this, arguments);
      }
      return addTileMask;
    }() // 全局 Mask
  }, {
    key: "addMask",
    value: function () {
      var _addMask = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(layer, mask) {
        var container;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              container = createLayerContainer(this.parent.sceneContainer);
              mask.setContainer(container, this.parent.sceneContainer);
              _context2.next = 4;
              return mask.init();
            case 4:
              layer.addMask(mask);
              this.tileMaskLayers.push(mask);
            case 6:
            case "end":
              return _context2.stop();
          }
        }, _callee2, this);
      }));
      function addMask(_x, _x2) {
        return _addMask.apply(this, arguments);
      }
      return addMask;
    }()
  }, {
    key: "addLayer",
    value: function () {
      var _addLayer = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(layer) {
        var container;
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) switch (_context3.prev = _context3.next) {
            case 0:
              // set flag
              layer.isTileLayer = true;
              container = createLayerContainer(this.parent.sceneContainer);
              layer.setContainer(container, this.parent.sceneContainer);
              this.layers.push(layer);
              _context3.next = 6;
              return layer.init();
            case 6:
            case "end":
              return _context3.stop();
          }
        }, _callee3, this);
      }));
      function addLayer(_x3) {
        return _addLayer.apply(this, arguments);
      }
      return addLayer;
    }()
  }, {
    key: "updateVisible",
    value: function updateVisible(value) {
      this.visible = value;
      this.updateOptions('visible', value);
    }
  }, {
    key: "updateOptions",
    value: function updateOptions(key, value) {
      this.layers.forEach(function (l) {
        l.updateLayerConfig(_defineProperty({}, key, value));
      });
    }

    /**
     * 一个 Tile 可能有多个 layer，但是在发生拾取、点击事件的时候只有一个生效
     */
  }, {
    key: "getMainLayer",
    value: function getMainLayer() {
      return this.layers[0];
    }
  }, {
    key: "getFeatures",
    value: function getFeatures(sourceLayer) {
      return [];
    }

    /**
     * 在一个 Tile 中可能存在一个相同 ID 的 feature
     * @param id
     * @returns
     */
  }, {
    key: "getFeatureById",
    value: function getFeatureById(id) {
      return [];
    }
  }, {
    key: "destroy",
    value: function destroy() {
      var _this$tileMask;
      (_this$tileMask = this.tileMask) === null || _this$tileMask === void 0 || _this$tileMask.destroy();
      this.layers.forEach(function (layer) {
        return layer.destroy();
      });
    }
  }]);
  return Tile;
}(EventEmitter);
export { Tile as default };

==> l7-layers-2.21.0.tgz: package/es/tile/tile/Tile.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _regeneratorRuntime from "@babel/runtime/regenerator";
function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
import { createLayerContainer } from '@antv/l7-core';
import { EventEmitter } from 'eventemitter3';
import PolygonLayer from "../../polygon";
import { isNeedMask } from "./util";
var Tile = /*#__PURE__*/function (_EventEmitter) {
  _inherits(Tile, _EventEmitter);
  var _super = _createSuper(Tile);
  function Tile(sourceTile, parent) {
    var _this;
    _classCallCheck(this, Tile);
    _this = _super.call(this);
    _defineProperty(_assertThisInitialized(_this), "visible", true);
    _defineProperty(_assertThisInitialized(_this), "layers", []);
    _defineProperty(_assertThisInitialized(_this), "isLoaded", false);
    _defineProperty(_assertThisInitialized(_this), "tileMaskLayers", []);
    _this.parent = parent;
    _this.sourceTile = sourceTile;
    _this.x = sourceTile.x;
    _this.y = sourceTile.y;
    _this.z = sourceTile.z;
    _this.key = "".concat(_this.x, "_").concat(_this.y, "_").concat(_this.z);
    return _this;
  }
  _createClass(Tile, [{
    key: "getLayers",
    value: function getLayers() {
      return this.layers;
    }

    // eslint-disable-next-line @typescript-eslint/no-unused-vars
  }, {
    key: "styleUpdate",
    value: function styleUpdate() {
      return;
    }
  }, {
    key: "lnglatInBounds",
    value: function lnglatInBounds(lnglat) {
      var _this$sourceTile$boun = _slicedToArray(this.sourceTile.bounds, 4),
        minLng = _this$sourceTile$boun[0],
        minLat = _this$sourceTile$boun[1],
        maxLng = _this$sourceTile$boun[2],
        maxLat = _this$sourceTile$boun[3];
      var lng = lnglat.lng,
        lat = lnglat.lat;
      return lng >= minLng && lng <= maxLng && lat >= minLat && lat <= maxLat;
    }
  }, {
    key: "getLayerOptions",
    value: function getLayerOptions() {
      var _options$maskLayers;
      var options = this.parent.getLayerConfig();
      return _objectSpread(_objectSpread({}, options), {}, {
        textAllowOverlap: true,
        // 文本允许重叠
        autoFit: false,
        maskLayers: this.getMaskLayer(),
        tileMask: isNeedMask(this.parent.type),
        mask: options.mask || ((_options$maskLayers = options.maskLayers) === null || _options$maskLayers === void 0 ? void 0 : _options$maskLayers.length) !== 0 && options.enableMask
      });
    }
    // 获取Mask 图层
  }, {
    key: "getMaskLayer",
    value: function getMaskLayer() {
      var _this2 = this;
      var _this$parent$getLayer = this.parent.getLayerConfig(),
        maskLayers = _this$parent$getLayer.maskLayers;
      var layers = [];
      maskLayers === null || maskLayers === void 0 || maskLayers.forEach(function (layer) {
        if (!layer.tileLayer) {
          // 非瓦片图层返回图层本身，瓦片图层返回对应的行列号图层
          layers.push(layer);
          return layer;
        }
        var tileLayer = layer.tileLayer;
        var tile = tileLayer.getTile(_this2.sourceTile.key);
        var l = tile === null || tile === void 0 ? void 0 : tile.getLayers()[0];
        if (l) {
          layers.push(l);
        }
      });
      return layers;
    }
  }, {
    key: "addTileMask",
    value: function () {
      var _addTileMask = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        var mask, container, mainLayer;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              mask = new PolygonLayer({
                name: 'mask',
                visible: true,
                enablePicking: false
              }).source({
                type: 'FeatureCollection',
                features: [this.sourceTile.bboxPolygon]
              }, {
                parser: {
                  type: 'geojson',
                  featureId: 'id'
                }
              }).shape('fill').color('#0f0').style({
                opacity: 0.5
              });
              container = createLayerContainer(this.parent.container);
              mask.setContainer(container);
              _context.next = 5;
              return mask.init();
            case 5:
              this.tileMask = mask;
              mainLayer = this.getMainLayer();
              if (mainLayer !== undefined) {
                mainLayer.tileMask = mask;
              }
              return _context.abrupt("return", mask);
            case 9:
            case "end":
              return _context.stop();
          }
        }, _callee, this);
      }));
      function addTileMask() {
        return _addTileMask.apply(this, arguments);
      }
      return addTileMask;
    }() // 全局 Mask
  }, {
    key: "addMask",
    value: function () {
      var _addMask = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(layer, mask) {
        var container;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              container = createLayerContainer(this.parent.container);
              mask.setContainer(container);
              _context2.next = 4;
              return mask.init();
            case 4:
              layer.addMask(mask);
              this.tileMaskLayers.push(mask);
            case 6:
            case "end":
              return _context2.stop();
          }
        }, _callee2, this);
      }));
      function addMask(_x, _x2) {
        return _addMask.apply(this, arguments);
      }
      return addMask;
    }()
  }, {
    key: "addLayer",
    value: function () {
      var _addLayer = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(layer) {
        var container;
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) switch (_context3.prev = _context3.next) {
            case 0:
              // set flag
              layer.isTileLayer = true;
              container = createLayerContainer(this.parent.container);
              layer.setContainer(container);
              this.layers.push(layer);
              _context3.next = 6;
              return layer.init();
            case 6:
            case "end":
              return _context3.stop();
          }
        }, _callee3, this);
      }));
      function addLayer(_x3) {
        return _addLayer.apply(this, arguments);
      }
      return addLayer;
    }()
  }, {
    key: "updateVisible",
    value: function updateVisible(value) {
      this.visible = value;
      this.updateOptions('visible', value);
    }
  }, {
    key: "updateOptions",
    value: function updateOptions(key, value) {
      this.layers.forEach(function (l) {
        l.updateLayerConfig(_defineProperty({}, key, value));
      });
    }

    /**
     * 一个 Tile 可能有多个 layer，但是在发生拾取、点击事件的时候只有一个生效
     */
  }, {
    key: "getMainLayer",
    value: function getMainLayer() {
      return this.layers[0];
    }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
  }, {
    key: "getFeatures",
    value: function getFeatures(sourceLayer) {
      return [];
    }

    /**
     * 在一个 Tile 中可能存在一个相同 ID 的 feature
     * @param id
     * @returns
     */
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
  }, {
    key: "getFeatureById",
    value: function getFeatureById(id) {
      return [];
    }
  }, {
    key: "destroy",
    value: function destroy() {
      var _this$tileMask;
      (_this$tileMask = this.tileMask) === null || _this$tileMask === void 0 || _this$tileMask.destroy();
      this.layers.forEach(function (layer) {
        return layer.destroy();
      });
    }
  }]);
  return Tile;
}(EventEmitter);
export { Tile as default };
